==> cxf-testutils-2.0.10.0-fuse-sources.jar: org/apache/type_test/doc/TestStructWithAnyAttributeResponse.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types2.StructWithAnyAttribute;


/**
 * <p>Java class for testStructWithAnyAttributeResponse element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testStructWithAnyAttributeResponse">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="return" type="{http://apache.org/type_test/types2}StructWithAnyAttribute"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types2}StructWithAnyAttribute"/>
 *           &lt;element name="z" type="{http://apache.org/type_test/types2}StructWithAnyAttribute"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testStructWithAnyAttributeResponse")
public class TestStructWithAnyAttributeResponse {

    @XmlElement(name = "return", namespace = "http://apache.org/type_test/doc", required = true)
    protected StructWithAnyAttribute _return;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected StructWithAnyAttribute y;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected StructWithAnyAttribute z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link StructWithAnyAttribute }
     *     
     */
    public StructWithAnyAttribute getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link StructWithAnyAttribute }
     *     
     */
    public void setReturn(StructWithAnyAttribute value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link StructWithAnyAttribute }
     *     
     */
    public StructWithAnyAttribute getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link StructWithAnyAttribute }
     *     
     */
    public void setY(StructWithAnyAttribute value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link StructWithAnyAttribute }
     *     
     */
    public StructWithAnyAttribute getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link StructWithAnyAttribute }
     *     
     */
    public void setZ(StructWithAnyAttribute value) {
        this.z = value;
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/doc/TestStructWithAnyAttributeResponse.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types2.StructWithAnyAttribute;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://apache.org/type_test/types2}StructWithAnyAttribute"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types2}StructWithAnyAttribute"/>
 *         &lt;element name="z" type="{http://apache.org/type_test/types2}StructWithAnyAttribute"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testStructWithAnyAttributeResponse")
public class TestStructWithAnyAttributeResponse {

    @XmlElement(name = "return", required = true)
    protected StructWithAnyAttribute _return;
    @XmlElement(required = true)
    protected StructWithAnyAttribute y;
    @XmlElement(required = true)
    protected StructWithAnyAttribute z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link StructWithAnyAttribute }
     *     
     */
    public StructWithAnyAttribute getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link StructWithAnyAttribute }
     *     
     */
    public void setReturn(StructWithAnyAttribute value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link StructWithAnyAttribute }
     *     
     */
    public StructWithAnyAttribute getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link StructWithAnyAttribute }
     *     
     */
    public void setY(StructWithAnyAttribute value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link StructWithAnyAttribute }
     *     
     */
    public StructWithAnyAttribute getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link StructWithAnyAttribute }
     *     
     */
    public void setZ(StructWithAnyAttribute value) {
        this.z = value;
    }

}
